"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const map_1 = __importDefault(require("../../utils/map"));
class MapBatteryBuilder {
    execute(report, knownHeadphone) {
        let isCharging, isDischarging, isConnected;
        const batteryPercent = this.calculateBattery(report[knownHeadphone.batteryPercentIdx]);
        if (knownHeadphone.chargingStatusIdx) {
            switch (report[knownHeadphone.chargingStatusIdx]) {
                case 0: // Not Connected
                    isConnected = false;
                    isCharging = undefined;
                    isDischarging = undefined;
                    break;
                case 1: // Charging
                    isConnected = true;
                    isCharging = true;
                    isDischarging = false;
                    break;
                case 3: // Discharging
                    isConnected = true;
                    isCharging = false;
                    isDischarging = true;
                    break;
            }
        }
        return { batteryPercent, isCharging, isDischarging, isConnected };
    }
    calculateBattery(batteryPercent) {
        const maxBattery = 0x04;
        const minBattery = 0x00;
        if (batteryPercent > maxBattery) {
            return 100;
        }
        return (0, map_1.default)(batteryPercent, minBattery, maxBattery, 0, 100);
    }
}
exports.default = MapBatteryBuilder;
