"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_hid_1 = __importDefault(require("node-hid"));
const host_1 = __importDefault(require("../utils/host"));
class Probe {
    constructor() {
        this.devices = node_hid_1.default.devices().filter((d) => d.vendorId === 4152);
    }
    testUnknownHeadset() {
        const knownBytes = [
            [0x0, 0x20],
            [0x06, 0x12],
            [0x06, 0x18],
            [0x40, 0xaa],
            [0x00, 0xb0],
        ];
        const foundHeadphones = this.devices.map((device) => {
            console.log('Probing', device.product);
            const devicePath = device.path;
            let hidDevice;
            if (host_1.default.isWin()) {
                if (devicePath === undefined) {
                    console.log("\tCouldn't connect");
                    return {
                        deviceProductName: device.product,
                        deviceProductId: device.productId,
                        matchedBytes: undefined,
                        matchedReport: undefined,
                        devicePath,
                    };
                }
                try {
                    hidDevice = new node_hid_1.default.HID(devicePath);
                }
                catch (_a) {
                    console.log("\tCouldn't connect");
                    return {
                        deviceProductName: device.product,
                        deviceProductId: device.productId,
                        matchedBytes: undefined,
                        matchedReport: undefined,
                        devicePath,
                    };
                }
            }
            else {
                try {
                    hidDevice = new node_hid_1.default.HID(device.vendorId, device.productId);
                }
                catch (_b) {
                    console.log("\tCouldn't connect");
                    return {
                        deviceProductName: device.product,
                        deviceProductId: device.productId,
                        matchedBytes: undefined,
                        matchedReport: undefined,
                        devicePath,
                    };
                }
            }
            let report = [];
            let matchedBytes;
            let matchedReport;
            knownBytes.some((bytes) => {
                console.log('\tWith', bytes);
                try {
                    hidDevice.write(bytes);
                    report = hidDevice.readTimeout(100);
                    if (report.length > 0) {
                        matchedBytes = bytes;
                        matchedReport = report;
                        console.log('\tSuccess!');
                        return true;
                    }
                }
                catch (_a) {
                    // skip
                }
            });
            return {
                deviceProductName: device.product,
                deviceProductId: device.productId,
                matchedBytes,
                matchedReport,
                devicePath,
            };
        });
        return foundHeadphones.filter((result) => {
            if (result.matchedReport === undefined) {
                return false;
            }
            return result.matchedReport.length > 0;
        });
    }
}
exports.default = Probe;
